/*
 * * Copyright (C) 2007 Tuomas Kulve <tuomas@kulve.fi>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 * USA.
 */

#include <hildon-cp-plugin/hildon-cp-plugin-interface.h>
#include <hildon/hildon-banner.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <sqlite3.h>


#define CPMO_META_STORAGE_FILE        "/home/user/.meta_storage"


static void _disable_oggs(void);

osso_return_t execute(osso_context_t *osso,
					  gpointer data,
					  gboolean user_activated)
{
    GtkWidget *dialog;
    GtkWidget *label;
    gint response;
  
    /* Create dialog with OK and Cancel buttons. Leave the separator out, 
     * as we do not have any content. */
    dialog = gtk_dialog_new_with_buttons(
        "Maps' OGGs",
        GTK_WINDOW(data),
        GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR,
        GTK_STOCK_OK,
        GTK_RESPONSE_OK,
        GTK_STOCK_CANCEL,
        GTK_RESPONSE_CANCEL,
        NULL);

    if (!user_activated)  {
        g_warning("State saving is not supported nor needed");
    }

    label = gtk_label_new("Ignore OGGs from the Maps?");
    gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), label);

    gtk_widget_show_all(dialog);

    /* Wait until user finishes the dialog. */
    response = gtk_dialog_run(GTK_DIALOG(dialog));

    if (response == GTK_RESPONSE_OK) {
        _disable_oggs();
    }

    /* Free the dialog (and it's children) */
    gtk_widget_destroy(GTK_WIDGET(dialog));

    return OSSO_OK;
}



/*
 * Open /home/user/.meta_storage and set Maps' OGGs' mimetype to
 * application/octet-stream.
 */
static void _disable_oggs(void)
{

    sqlite3 *db;
    char *zErrMsg = 0;
    int rc;
    char *update_sql =
        "update Metadata set MIME='application/octet-stream' "
        "where Filename like '%/map/navicore/sounds/%';";

    rc = sqlite3_open(CPMO_META_STORAGE_FILE, &db);
    if (rc){
        g_warning("Can't open database: %s\n", sqlite3_errmsg(db));
        hildon_banner_show_informationf(NULL,
                                        NULL,
                                        "Can't open database: %s\n", 
                                        sqlite3_errmsg(db));

        sqlite3_close(db);
        return;
    }

    rc = sqlite3_exec(db, update_sql, NULL, 0, &zErrMsg);
    if (rc != SQLITE_OK) {
        g_warning("SQL error: %s\n", zErrMsg);
       hildon_banner_show_informationf(NULL,
                                       NULL,
                                       "SQL error: %s\n", zErrMsg);
       sqlite3_free(zErrMsg);
    }

    sqlite3_close(db);

    return;
}


/* Emacs indentatation information
 * Local Variables:
 * c-file-style:"stroustrup"
 * c-basic-offset:4
 * indent-tabs-mode:nil
 * End:
 */

